Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ExpectOption ¶
type ExpectOption func(*expectOpts)
func MinTimes ¶ added in v0.4.0
func MinTimes(n int) ExpectOption
MinTimes sets the minimum number of times the expectation should be met. When n is 0, the expectation acts as a stub and can be called any number of times. Panics if n is negative.
func Times ¶
func Times(n int) ExpectOption
Times sets the number of times the expectation should be met. Panics if n is negative.
Click to show internal directories.
Click to hide internal directories.